package
module
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Mar 22, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
personal-go-modules
个人编写并使用的 Golang Modules仓库
Documentation
¶
type Stack[T any] struct {
Items []T
Top int
}
定义一个泛型的Stack结构体
func (s *Stack[T]) Push(item T)
实现Push方法来添加元素
Source Files
¶
Click to show internal directories.
Click to hide internal directories.